@@ -2,7 +2,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2004-2024 Univention GmbH
+# Copyright 2004-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -54,7 +54,7 @@ def month_map(month):
         return '*'
     if month in month_list:
         return month_list.index(month)
-    return None  # FIXME
+    return None  # FIXME:
 
 
 def weekday_map(weekday):
@@ -75,7 +75,7 @@ def weekday_map(weekday):
         return '*'
     if weekday in weekday_list:
         return weekday_list.index(weekday)
-    return None  # FIXME
+    return None  # FIXME:
 
 
 def month_reverse_map(month):
@@ -96,7 +96,7 @@ def month_reverse_map(month):
         return '*'
     if int(month) < len(month_list):
         return month_list[int(month)]
-    return None  # FIXME
+    return None  # FIXME:
 
 
 def weekday_reverse_map(weekday):
@@ -117,7 +117,7 @@ def weekday_reverse_map(weekday):
         return '*'
     if int(weekday) < len(weekday_list):
         return weekday_list[int(weekday)]
-    return None  # FIXME
+    return None  # FIXME:
 
 
 def cron_create(cronlist):
