@@ -114,6 +114,11 @@ class object(univention.admin.handlers.simpleLdap):
         # type: (str, univention.admin.handlers._Attributes, bool) -> bool
         return b'univentionBlocklist' in attr.get('objectClass', [])
 
+    # do not set univentionObjectIdentifier on blocklist objects - they are saved in a different LDAP base
+    @classmethod
+    def _register_univention_object_identifier_property(cls, module):
+        return
+
 
 lookup_filter = object.lookup_filter
 lookup = object.lookup
