@@ -2,7 +2,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2004-2024 Univention GmbH
+# Copyright 2004-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -114,7 +114,7 @@ class object(univention.admin.handlers.simpleLdap, PKIIntegration):
         super().open()
         self.pki_open()
 
-        self.options = ['samba']  # FIXME/TODO
+        self.options = ['samba']  # FIXME: TODO
         self.modifypassword = 1
         if self.exists():
             self['password'] = '********'
