@@ -2,7 +2,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2004-2024 Univention GmbH
+# Copyright 2004-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -233,7 +233,7 @@ def IgnoreNone(value, encoding=()):
     """
     if value != 'None':
         return value.encode(*encoding)
-    return None  # FIXME
+    return None  # FIXME:
 
 
 def _stringToInt(value):
