@@ -253,7 +253,7 @@ def init(lo: univention.admin.uldap.access, position: univention.admin.uldap.pos
                 if tmpl not in ([''], []):
                     for option in module.options.keys():
                         module.options[option].default = option in tmpl
-            elif key not in {"name", "description"}:  # these keys are part of the template itself
+            elif key not in {"name", "description", "univentionObjectIdentifier"}:  # these keys are part of the template itself
                 module.property_descriptions[key].base_default = copy.copy(tmpl)
                 module.property_descriptions[key].templates.append(template_object)
         log.debug('modules_init: module.property_description after template: %s', module.property_descriptions)
