@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2004-2024 Univention GmbH
+# Copyright 2004-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -134,8 +134,7 @@ def doit(arglist):
     if len(args) == 1:
         if scope == 'machine':
             machine = args[0]
-            if machine.endswith('$'):
-                machine = machine[:-1]
+            machine = machine.removesuffix('$')
             if configRegistry.get('samba/defaultcontainer/computer'):
                 position.setDn(configRegistry['samba/defaultcontainer/computer'])
             else:
